@@ -11,7 +11,7 @@ use crate::frame::groupby::*;
 use crate::frame::hash_join::*;
 use crate::prelude::*;
 
-impl IntoSeries for DatetimeChunked {
+unsafe impl IntoSeries for DatetimeChunked {
     fn into_series(self) -> Series {
         Series(Arc::new(SeriesWrap(self)))
     }
@@ -352,9 +352,9 @@ impl SeriesTrait for SeriesWrap<DatetimeChunked> {
             .into_series()
     }
 
-    fn expand_at_index(&self, index: usize, length: usize) -> Series {
+    fn new_from_index(&self, index: usize, length: usize) -> Series {
         self.0
-            .expand_at_index(index, length)
+            .new_from_index(index, length)
             .into_datetime(self.0.time_unit(), self.0.time_zone().clone())
             .into_series()
     }
