@@ -205,7 +205,11 @@ pub fn get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
             #[cfg(all(feature = "dtype-date", feature = "dtype-time"))]
             (Date, Time) => Some(Int64),
 
-            // every known type can be casted to a string
+            // every known type can be casted to a string except binary
+            #[cfg(feature = "dtype-binary")]
+            (dt, Utf8) if dt != &DataType::Unknown && dt != &DataType::Binary => Some(Utf8),
+
+            #[cfg(not(feature = "dtype-binary"))]
             (dt, Utf8) if dt != &DataType::Unknown => Some(Utf8),
 
             (dt, Null) => Some(dt.clone()),
@@ -240,7 +244,11 @@ pub fn get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
             // None and Some("<tz>") timezones
             // we cast from more precision to higher precision as that always fits with occasional loss of precision
             #[cfg(feature = "dtype-datetime")]
-            (Datetime(tu_l, tz_l), Datetime(tu_r, tz_r)) if tz_l.is_none() && tz_r.is_some() => {
+            (Datetime(tu_l, tz_l), Datetime(tu_r, tz_r)) if
+                // both are none
+                tz_l.is_none() && tz_r.is_some()
+                // both have the same time zone
+                || (tz_l.is_some() && (tz_l == tz_r)) => {
                 let tu = get_time_units(tu_l, tu_r);
                 Some(Datetime(tu, tz_r.clone()))
             }
@@ -270,6 +278,15 @@ pub fn get_supertype(l: &DataType, r: &DataType) -> Option<DataType> {
                     Some(Struct(new_fields))
                 }
             }
+            #[cfg(feature = "dtype-struct")]
+            (Struct(fields_a), rhs) if rhs.is_numeric() => {
+                let mut new_fields = Vec::with_capacity(fields_a.len());
+                for a in fields_a {
+                    let st = get_supertype(&a.dtype, rhs)?;
+                    new_fields.push(Field::new(&a.name, st))
+                }
+                Some(Struct(new_fields))
+            }
             _ => None,
         }
     }
