@@ -522,9 +522,16 @@ impl LazyFrame {
         )
     }
 
-    fn prepare_collect(self) -> PolarsResult<(ExecutionState, Box<dyn Executor>)> {
+    #[allow(unused_mut)]
+    fn prepare_collect(mut self) -> PolarsResult<(ExecutionState, Box<dyn Executor>)> {
         let file_caching = self.opt_state.file_caching;
         let streaming = self.opt_state.streaming;
+
+        #[cfg(feature = "cse")]
+        if streaming && self.opt_state.common_subplan_elimination {
+            eprintln!("Cannot combine 'streaming' with 'common_subplan_elimination'. CSE will be turned off.");
+            self.opt_state.common_subplan_elimination = false;
+        }
         let mut expr_arena = Arena::with_capacity(256);
         let mut lp_arena = Arena::with_capacity(128);
         let mut scratch = vec![];
