@@ -17,7 +17,7 @@ use super::HASHMAP_INIT_SIZE;
 use crate::executors::sinks::groupby::aggregates::AggregateFunction;
 use crate::executors::sinks::groupby::utils::compute_slices;
 use crate::expressions::PhysicalPipedExpr;
-use crate::operators::{DataChunk, PExecutionContext, Sink, SinkResult};
+use crate::operators::{DataChunk, FinalizedSink, PExecutionContext, Sink, SinkResult};
 
 // This is the hash and the Index offset in the linear buffer
 type Key = (u64, IdxSize);
@@ -108,6 +108,86 @@ impl GenericGroupbySink {
     fn number_of_keys(&self) -> usize {
         self.key_columns.len()
     }
+
+    fn pre_finalize(&mut self) -> PolarsResult<Vec<DataFrame>> {
+        let mut aggregators = std::mem::take(&mut self.aggregators);
+        let n_keys = self.number_of_keys();
+        let slices = compute_slices(&self.pre_agg_partitions, self.slice);
+
+        POOL.install(|| {
+            let dfs =
+                self.pre_agg_partitions
+                    .par_iter()
+                    .zip(aggregators.par_iter_mut())
+                    .zip(self.keys.par_iter())
+                    .zip(slices.par_iter())
+                    .filter_map(|(((agg_map, agg_fns), current_keys), slice)| {
+                        let (offset, slice_len) = (*slice)?;
+                        if agg_map.is_empty() {
+                            return None;
+                        }
+                        let mut key_builders = self
+                            .output_schema
+                            .iter_dtypes()
+                            .take(n_keys)
+                            .map(|dtype| AnyValueBuffer::new(dtype, agg_map.len()))
+                            .collect::<Vec<_>>();
+                        let dtypes = agg_fns
+                            .iter()
+                            .take(self.number_of_aggs())
+                            .map(|func| func.dtype())
+                            .collect::<Vec<_>>();
+
+                        let mut buffers = dtypes
+                            .iter()
+                            .map(|dtype| AnyValueBuffer::new(dtype, slice_len))
+                            .collect::<Vec<_>>();
+
+                        agg_map.into_iter().skip(offset).take(slice_len).for_each(
+                            |(k, &offset)| {
+                                let keys_offset = k.1 as usize;
+                                let keys = unsafe {
+                                    current_keys
+                                        .get_unchecked_release(keys_offset..keys_offset + n_keys)
+                                };
+
+                                for (key, key_builder) in keys.iter().zip(key_builders.iter_mut()) {
+                                    key_builder.add(key.as_borrowed());
+                                }
+
+                                for (i, buffer) in (offset as usize
+                                    ..offset as usize + self.aggregation_columns.len())
+                                    .zip(buffers.iter_mut())
+                                {
+                                    unsafe {
+                                        let agg_fn = agg_fns.get_unchecked_release_mut(i);
+                                        let av = agg_fn.finalize();
+                                        buffer.add(av);
+                                    }
+                                }
+                            },
+                        );
+
+                        let mut cols = Vec::with_capacity(n_keys + self.number_of_aggs());
+                        for key_builder in key_builders {
+                            cols.push(key_builder.into_series());
+                        }
+                        cols.extend(buffers.into_iter().map(|buf| buf.into_series()));
+                        for (s, (name, dtype)) in cols.iter_mut().zip(self.output_schema.iter()) {
+                            if s.name() != name {
+                                s.rename(name);
+                            }
+                            if s.dtype() != dtype {
+                                *s = s.cast(dtype).unwrap()
+                            }
+                        }
+                        Some(DataFrame::new_no_checks(cols))
+                    })
+                    .collect::<Vec<_>>();
+
+            Ok(dfs)
+        })
+    }
 }
 
 impl Sink for GenericGroupbySink {
@@ -223,7 +303,7 @@ impl Sink for GenericGroupbySink {
         Ok(SinkResult::CanHaveMoreInput)
     }
 
-    fn combine(&mut self, other: Box<dyn Sink>) {
+    fn combine(&mut self, mut other: Box<dyn Sink>) {
         // don't parallel this as this is already done in parallel.
 
         let other = other.as_any().downcast_ref::<Self>().unwrap();
@@ -326,86 +406,13 @@ impl Sink for GenericGroupbySink {
         Box::new(new)
     }
 
-    fn finalize(&mut self) -> PolarsResult<DataFrame> {
-        let mut aggregators = std::mem::take(&mut self.aggregators);
-        let n_keys = self.number_of_keys();
-        let slices = compute_slices(&self.pre_agg_partitions, self.slice);
-
-        POOL.install(|| {
-            let dfs =
-                self.pre_agg_partitions
-                    .par_iter()
-                    .zip(aggregators.par_iter_mut())
-                    .zip(self.keys.par_iter())
-                    .zip(slices.par_iter())
-                    .filter_map(|(((agg_map, agg_fns), current_keys), slice)| {
-                        let (offset, slice_len) = (*slice)?;
-                        if agg_map.is_empty() {
-                            return None;
-                        }
-                        let mut key_builders = self
-                            .output_schema
-                            .iter_dtypes()
-                            .take(n_keys)
-                            .map(|dtype| AnyValueBuffer::new(dtype, agg_map.len()))
-                            .collect::<Vec<_>>();
-                        let dtypes = agg_fns
-                            .iter()
-                            .take(self.number_of_aggs())
-                            .map(|func| func.dtype())
-                            .collect::<Vec<_>>();
-
-                        let mut buffers = dtypes
-                            .iter()
-                            .map(|dtype| AnyValueBuffer::new(dtype, slice_len))
-                            .collect::<Vec<_>>();
-
-                        agg_map.into_iter().skip(offset).take(slice_len).for_each(
-                            |(k, &offset)| {
-                                let keys_offset = k.1 as usize;
-                                let keys = unsafe {
-                                    current_keys
-                                        .get_unchecked_release(keys_offset..keys_offset + n_keys)
-                                };
-
-                                for (key, key_builder) in keys.iter().zip(key_builders.iter_mut()) {
-                                    key_builder.add(key.as_borrowed());
-                                }
-
-                                for (i, buffer) in (offset as usize
-                                    ..offset as usize + self.aggregation_columns.len())
-                                    .zip(buffers.iter_mut())
-                                {
-                                    unsafe {
-                                        let agg_fn = agg_fns.get_unchecked_release_mut(i);
-                                        let av = agg_fn.finalize();
-                                        buffer.add(av);
-                                    }
-                                }
-                            },
-                        );
-
-                        let mut cols = Vec::with_capacity(n_keys + self.number_of_aggs());
-                        for key_builder in key_builders {
-                            cols.push(key_builder.into_series());
-                        }
-                        cols.extend(buffers.into_iter().map(|buf| buf.into_series()));
-                        for (s, (name, dtype)) in cols.iter_mut().zip(self.output_schema.iter()) {
-                            if s.name() != name {
-                                s.rename(name);
-                            }
-                            if s.dtype() != dtype {
-                                *s = s.cast(dtype).unwrap()
-                            }
-                        }
-                        Some(DataFrame::new_no_checks(cols))
-                    })
-                    .collect::<Vec<_>>();
-            Ok(accumulate_dataframes_vertical_unchecked(dfs))
-        })
+    fn finalize(&mut self) -> PolarsResult<FinalizedSink> {
+        let dfs = self.pre_finalize()?;
+        let mut df = accumulate_dataframes_vertical_unchecked(dfs);
+        DataFrame::new(std::mem::take(df.get_columns_mut())).map(FinalizedSink::Finished)
     }
 
-    fn as_any(&self) -> &dyn Any {
+    fn as_any(&mut self) -> &mut dyn Any {
         self
     }
 }
