@@ -64,7 +64,7 @@ from polars.internals import BatchedCsvReader
 # TODO remove need for wrap_df
 from polars.internals.dataframe import wrap_df  # noqa: F401
 from polars.internals.dataframe import DataFrame
-from polars.internals.expr import Expr
+from polars.internals.expr.expr import Expr
 from polars.internals.functions import (
     align_frames,
     concat,
@@ -93,6 +93,7 @@ from polars.internals.lazy_functions import (
     count,
     cov,
     cumfold,
+    cumreduce,
     cumsum,
     duration,
     element,
@@ -100,6 +101,7 @@ from polars.internals.lazy_functions import (
     first,
     fold,
     format,
+    from_epoch,
     groups,
     head,
     last,
@@ -112,6 +114,7 @@ from polars.internals.lazy_functions import (
     n_unique,
     pearson_corr,
     quantile,
+    reduce,
     repeat,
     select,
     spearman_rank_corr,
@@ -126,7 +129,7 @@ from polars.internals.lazyframe import LazyFrame
 
 # TODO: remove need for wrap_s
 from polars.internals.series import wrap_s  # noqa: F401
-from polars.internals.series import Series
+from polars.internals.series.series import Series
 from polars.internals.sql import SQLContext
 from polars.internals.whenthen import when
 from polars.io import (
@@ -254,6 +257,8 @@ __all__ = [
     "apply",
     "fold",
     "cumfold",
+    "reduce",
+    "cumreduce",
     "cumsum",
     "any",
     "all",
@@ -266,6 +271,7 @@ __all__ = [
     "collect_all",
     "exclude",
     "format",
+    "from_epoch",
     "datetime",  # named _datetime, see import above
     "date",  # name _date, see import above
     "list",  # named to_list, see import above
