@@ -7,17 +7,21 @@ from typing import TYPE_CHECKING, Any, Callable, Sequence, cast, overload
 
 from polars import internals as pli
 from polars.datatypes import (
+    DTYPE_TEMPORAL_UNITS,
     DataType,
     Date,
     Datetime,
     Duration,
+    Int64,
     PolarsDataType,
     Time,
     UInt32,
     is_polars_dtype,
     py_type_to_dtype,
 )
-from polars.import_check import _NUMPY_AVAILABLE, lazy_isinstance, numpy_mod
+from polars.dependencies import _NUMPY_TYPE
+from polars.dependencies import numpy as np
+from polars.internals.type_aliases import EpochTimeUnit
 from polars.utils import (
     _datetime_to_pl_timestamp,
     _time_to_pl_time,
@@ -38,6 +42,7 @@ try:
     from polars.polars import count as _count
     from polars.polars import cov as pycov
     from polars.polars import cumfold as pycumfold
+    from polars.polars import cumreduce as pycumreduce
     from polars.polars import dtype_cols as _dtype_cols
     from polars.polars import first as _first
     from polars.polars import fold as pyfold
@@ -48,6 +53,7 @@ try:
     from polars.polars import min_exprs as _min_exprs
     from polars.polars import pearson_corr as pypearson_corr
     from polars.polars import py_datetime, py_duration
+    from polars.polars import reduce as pyreduce
     from polars.polars import repeat as _repeat
     from polars.polars import spearman_rank_corr as pyspearman_rank_corr
     from polars.polars import sum_exprs as _sum_exprs
@@ -62,8 +68,6 @@ else:
     from typing_extensions import Literal
 
 if TYPE_CHECKING:
-    import numpy as np
-
     from polars.internals.type_aliases import InterpolationMethod, IntoExpr, TimeUnit
 
 
@@ -748,10 +752,7 @@ def lit(
             return e
         return e.alias(name)
 
-    if _NUMPY_AVAILABLE and lazy_isinstance(
-        value, "numpy", lambda: numpy_mod().ndarray
-    ):
-        value = cast("np.ndarray[Any, Any]", value)
+    if _NUMPY_TYPE(value) and isinstance(value, np.ndarray):
         return lit(pli.Series("", value))
 
     if dtype:
@@ -972,13 +973,16 @@ def map(
 
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(_map_mul(exprs, f, return_dtype, apply_groups=False))
+    return pli.wrap_expr(
+        _map_mul(exprs, f, return_dtype, apply_groups=False, returns_scalar=False)
+    )
 
 
 def apply(
     exprs: Sequence[str | pli.Expr],
     f: Callable[[Sequence[pli.Series]], pli.Series | Any],
     return_dtype: type[DataType] | None = None,
+    returns_scalar: bool = True,
 ) -> pli.Expr:
     """
     Apply a custom/user-defined function (UDF) in a GroupBy context.
@@ -999,6 +1003,8 @@ def apply(
         Function to apply over the input
     return_dtype
         dtype of the output Series
+    returns_scalar
+        If the function returns a single scalar as output.
 
     Returns
     -------
@@ -1006,7 +1012,11 @@ def apply(
 
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
-    return pli.wrap_expr(_map_mul(exprs, f, return_dtype, apply_groups=True))
+    return pli.wrap_expr(
+        _map_mul(
+            exprs, f, return_dtype, apply_groups=True, returns_scalar=returns_scalar
+        )
+    )
 
 
 def fold(
@@ -1028,6 +1038,11 @@ def fold(
     exprs
         Expressions to aggregate over. May also be a wildcard expression.
 
+    Notes
+    -----
+    If you simply want the first encountered expression as accumulator,
+    consider using ``reduce``.
+
     """
     # in case of pl.col("*")
     acc = pli.expr_to_lit_or_expr(acc, str_to_lit=True)
@@ -1038,6 +1053,34 @@ def fold(
     return pli.wrap_expr(pyfold(acc._pyexpr, f, exprs))
 
 
+def reduce(
+    f: Callable[[pli.Series, pli.Series], pli.Series],
+    exprs: Sequence[pli.Expr | str] | pli.Expr,
+) -> pli.Expr:
+    """
+    Accumulate over multiple columns horizontally/ row wise with a left fold.
+
+    Parameters
+    ----------
+    f
+        Function to apply over the accumulator and the value.
+        Fn(acc, value) -> new_value
+    exprs
+        Expressions to aggregate over. May also be a wildcard expression.
+
+    Notes
+    -----
+    See ``fold`` for the version with an explicit accumulator.
+
+    """
+    # in case of pl.col("*")
+    if isinstance(exprs, pli.Expr):
+        exprs = [exprs]
+
+    exprs = pli.selection_to_pyexpr_list(exprs)
+    return pli.wrap_expr(pyreduce(f, exprs))
+
+
 def cumfold(
     acc: IntoExpr,
     f: Callable[[pli.Series, pli.Series], pli.Series],
@@ -1062,6 +1105,11 @@ def cumfold(
     include_init
         Include the initial accumulator state as struct field.
 
+    Notes
+    -----
+    If you simply want the first encountered expression as accumulator,
+    consider using ``cumreduce``.
+
     """  # noqa E501
     # in case of pl.col("*")
     acc = pli.expr_to_lit_or_expr(acc, str_to_lit=True)
@@ -1072,6 +1120,32 @@ def cumfold(
     return pli.wrap_expr(pycumfold(acc._pyexpr, f, exprs, include_init))
 
 
+def cumreduce(
+    f: Callable[[pli.Series, pli.Series], pli.Series],
+    exprs: Sequence[pli.Expr | str] | pli.Expr,
+) -> pli.Expr:
+    """
+    Cumulatively accumulate over multiple columns horizontally/ row wise with a left fold.
+
+    Every cumulative result is added as a separate field in a Struct column.
+
+    Parameters
+    ----------
+    f
+        Function to apply over the accumulator and the value.
+        Fn(acc, value) -> new_value
+    exprs
+        Expressions to aggregate over. May also be a wildcard expression.
+
+    """  # noqa E501
+    # in case of pl.col("*")
+    if isinstance(exprs, pli.Expr):
+        exprs = [exprs]
+
+    exprs = pli.selection_to_pyexpr_list(exprs)
+    return pli.wrap_expr(pycumreduce(f, exprs))
+
+
 def any(name: str | Sequence[str] | Sequence[pli.Expr] | pli.Expr) -> pli.Expr:
     """Evaluate columnwise or elementwise with a bitwise OR operation."""
     if isinstance(name, str):
@@ -1313,11 +1387,13 @@ def arange(
     """
     low = pli.expr_to_lit_or_expr(low, str_to_lit=False)
     high = pli.expr_to_lit_or_expr(high, str_to_lit=False)
-
     if eager:
-        df = pli.DataFrame({"a": [1]})
-        return df.select(arange(low, high, step).alias("arange"))["arange"]
-
+        return (
+            pli.DataFrame()
+            .select(arange(low, high, step))
+            .to_series()
+            .rename("arange", in_place=True)
+        )
     return pli.wrap_expr(pyarange(low._pyexpr, high._pyexpr, step))
 
 
@@ -2048,3 +2124,122 @@ def coalesce(
     """
     exprs = pli.selection_to_pyexpr_list(exprs)
     return pli.wrap_expr(_coalesce_exprs(exprs))
+
+
+@overload
+def from_epoch(
+    column: str | pli.Expr | pli.Series,
+    unit: EpochTimeUnit = ...,
+    *,
+    eager: Literal[False],
+) -> pli.Expr:
+    ...
+
+
+@overload
+def from_epoch(
+    column: str | pli.Expr | pli.Series | Sequence[int],
+    unit: EpochTimeUnit = ...,
+    *,
+    eager: Literal[True],
+) -> pli.Series:
+    ...
+
+
+@overload
+def from_epoch(
+    column: pli.Series | Sequence[int],
+    unit: EpochTimeUnit = ...,
+    *,
+    eager: Literal[True] = ...,
+) -> pli.Series:
+    ...
+
+
+@overload
+def from_epoch(
+    column: str | pli.Expr,
+    unit: EpochTimeUnit = ...,
+    *,
+    eager: Literal[False] = ...,
+) -> pli.Expr:
+    ...
+
+
+@overload
+def from_epoch(
+    column: str | pli.Expr | pli.Series | Sequence[int],
+    unit: EpochTimeUnit = ...,
+    *,
+    eager: bool = ...,
+) -> pli.Expr | pli.Series:
+    ...
+
+
+def from_epoch(
+    column: str | pli.Expr | pli.Series | Sequence[int],
+    unit: EpochTimeUnit = "s",
+    *,
+    eager: bool = False,
+) -> pli.Expr | pli.Series:
+    """
+    Utility function that parses an epoch timestamp (or Unix time) to Polars Date(time).
+
+    Depending on the `unit` provided, this function will return a different dtype:
+    - unit="d" returns pl.Date
+    - unit="s" returns pl.Datetime["us"] (pl.Datetime's default)
+    - unit="ms" returns pl.Datetime["ms"]
+    - unit="us" returns pl.Datetime["us"]
+    - unit="ns" returns pl.Datetime["ns"]
+
+    Parameters
+    ----------
+    column
+        Series or expression to parse integers to pl.Datetime.
+    unit
+        The unit of the timesteps since epoch time.
+    eager
+        If eager evaluation is `True`, a Series is returned instead of an Expr.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"timestamp": [1666683077, 1666683099]}).lazy()
+    >>> df.select(pl.from_epoch(pl.col("timestamp"), unit="s")).collect()
+    shape: (2, 1)
+    ┌─────────────────────┐
+    │ timestamp           │
+    │ ---                 │
+    │ datetime[μs]        │
+    ╞═════════════════════╡
+    │ 2022-10-25 07:31:17 │
+    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+    │ 2022-10-25 07:31:39 │
+    └─────────────────────┘
+
+    """
+    if isinstance(column, str):
+        column = col(column)
+    elif not isinstance(column, (pli.Series, pli.Expr)):
+        column = pli.Series(column)  # Sequence input handled by Series constructor
+
+    if unit == "d":
+        expr = column.cast(Date)
+    elif unit == "s":
+        expr = (column.cast(Int64) * 1_000_000).cast(Datetime("us"))
+    elif unit in DTYPE_TEMPORAL_UNITS:
+        expr = column.cast(Datetime(unit))
+    else:
+        raise ValueError(
+            f"'unit' must be one of {{'ns', 'us', 'ms', 's', 'd'}}, got '{unit}'."
+        )
+
+    if eager:
+        if not isinstance(column, pli.Series):
+            raise ValueError(
+                "expected 'Series or Sequence' in 'from_epoch' if 'eager=True', got"
+                f" {type(column)}"
+            )
+        else:
+            return column.to_frame().select(expr).to_series()
+    else:
+        return expr
