@@ -53,7 +53,9 @@ def _is_empty_method(func: SeriesMethod) -> bool:
     """
     fc = func.__code__
     return (fc.co_code in _EMPTY_BYTECODE) and (
-        len(fc.co_consts) == 2 and fc.co_consts[1] is None
+        (len(fc.co_consts) == 2 and fc.co_consts[1] is None)
+        # account for potentially optimized-out docstrings
+        or (sys.flags.optimize == 2 and fc.co_consts == (None,))
     )
 
 
