@@ -116,11 +116,21 @@ fn fold(acc: PyExpr, lambda: PyObject, exprs: Vec<PyExpr>) -> PyExpr {
     dsl::fold(acc, lambda, exprs)
 }
 
+#[pyfunction]
+fn reduce(lambda: PyObject, exprs: Vec<PyExpr>) -> PyExpr {
+    dsl::reduce(lambda, exprs)
+}
+
 #[pyfunction]
 fn cumfold(acc: PyExpr, lambda: PyObject, exprs: Vec<PyExpr>, include_init: bool) -> PyExpr {
     dsl::cumfold(acc, lambda, exprs, include_init)
 }
 
+#[pyfunction]
+fn cumreduce(lambda: PyObject, exprs: Vec<PyExpr>) -> PyExpr {
+    dsl::cumreduce(lambda, exprs)
+}
+
 #[pyfunction]
 fn arange(low: PyExpr, high: PyExpr, step: usize) -> PyExpr {
     polars::lazy::dsl::arange(low.inner, high.inner, step).into()
@@ -577,6 +587,8 @@ fn polars(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_wrapped(wrap_pyfunction!(lit)).unwrap();
     m.add_wrapped(wrap_pyfunction!(fold)).unwrap();
     m.add_wrapped(wrap_pyfunction!(cumfold)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(reduce)).unwrap();
+    m.add_wrapped(wrap_pyfunction!(cumreduce)).unwrap();
     m.add_wrapped(wrap_pyfunction!(binary_expr)).unwrap();
     m.add_wrapped(wrap_pyfunction!(arange)).unwrap();
     m.add_wrapped(wrap_pyfunction!(pearson_corr)).unwrap();
