@@ -12,7 +12,7 @@ from hypothesis.strategies import booleans, floats, sampled_from
 import polars as pl
 from polars.internals.expr.expr import _prepare_alpha
 from polars.testing import assert_series_equal
-from polars.testing._parametric import series
+from polars.testing.parametric import series
 
 
 def alpha_guard(**decay_param: float) -> bool:
@@ -141,4 +141,4 @@ def test_series_timeunits(
         if isinstance(us, int)
     ):
         for ns, us in zip(s2.dt.nanoseconds(), micros):
-            assert ns == (us * 1000)  # type: ignore[operator]
+            assert ns == (us * 1000)
