@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import os
+from datetime import date, datetime
 from functools import reduce
 from operator import add
 from string import ascii_letters
@@ -12,7 +13,9 @@ from _pytest.capture import CaptureFixture
 
 import polars as pl
 from polars import col, lit, when
+from polars.datatypes import PolarsDataType
 from polars.testing import assert_frame_equal
+from polars.testing.asserts import assert_series_equal
 
 
 def test_lazy() -> None:
@@ -123,25 +126,6 @@ def test_agg() -> None:
     assert res.row(0) == (1, 1.0)
 
 
-def test_fold() -> None:
-    df = pl.DataFrame({"a": [1, 2, 3], "b": [1.0, 2.0, 3.0]})
-    out = df.select(
-        [
-            pl.sum(["a", "b"]),
-            pl.max(["a", pl.col("b") ** 2]),
-            pl.min(["a", pl.col("b") ** 2]),
-        ]
-    )
-    assert out["sum"].series_equal(pl.Series("sum", [2.0, 4.0, 6.0]))
-    assert out["max"].series_equal(pl.Series("max", [1.0, 4.0, 9.0]))
-    assert out["min"].series_equal(pl.Series("min", [1.0, 2.0, 3.0]))
-
-    out = df.select(
-        pl.fold(acc=lit(0), f=lambda acc, x: acc + x, exprs=pl.col("*")).alias("foo")
-    )
-    assert out["foo"].to_list() == [2, 4, 6]
-
-
 def test_or() -> None:
     df = pl.DataFrame({"a": [1, 2, 3], "b": [1.0, 2.0, 3.0]})
     out = df.lazy().filter((pl.col("a") == 1) | (pl.col("b") > 2)).collect()
@@ -1517,3 +1501,50 @@ def test_quadratic_behavior_4736() -> None:
     # our tests it has passed.
     df = pl.DataFrame(columns=list(ascii_letters))
     df.lazy().select(reduce(add, (pl.col(fld) for fld in df.columns)))
+
+
+@pytest.mark.parametrize("input_dtype", [pl.Utf8, pl.Int64, pl.Float64])
+def test_from_epoch(input_dtype: PolarsDataType) -> None:
+    ldf = pl.DataFrame(
+        [
+            pl.Series("timestamp_d", [13285]).cast(input_dtype),
+            pl.Series("timestamp_s", [1147880044]).cast(input_dtype),
+            pl.Series("timestamp_ms", [1147880044 * 1_000]).cast(input_dtype),
+            pl.Series("timestamp_us", [1147880044 * 1_000_000]).cast(input_dtype),
+            pl.Series("timestamp_ns", [1147880044 * 1_000_000_000]).cast(input_dtype),
+        ]
+    ).lazy()
+
+    exp_dt = datetime(2006, 5, 17, 15, 34, 4)
+    expected = pl.DataFrame(
+        [
+            pl.Series("timestamp_d", [date(2006, 5, 17)]),
+            pl.Series("timestamp_s", [exp_dt]),  # s is no Polars dtype, defaults to us
+            pl.Series("timestamp_ms", [exp_dt]).cast(pl.Datetime("ms")),
+            pl.Series("timestamp_us", [exp_dt]),  # us is Polars Datetime default
+            pl.Series("timestamp_ns", [exp_dt]).cast(pl.Datetime("ns")),
+        ]
+    )
+
+    ldf_result = ldf.select(
+        [
+            pl.from_epoch(pl.col("timestamp_d"), unit="d"),
+            pl.from_epoch(pl.col("timestamp_s"), unit="s"),
+            pl.from_epoch(pl.col("timestamp_ms"), unit="ms"),
+            pl.from_epoch(pl.col("timestamp_us"), unit="us"),
+            pl.from_epoch(pl.col("timestamp_ns"), unit="ns"),
+        ]
+    ).collect()
+
+    assert_frame_equal(ldf_result, expected)
+
+    with pytest.raises(ValueError):
+        ts_col = pl.col("timestamp_s")
+        _ = ldf.select(pl.from_epoch(ts_col, unit="s2"))  # type: ignore[call-overload]
+
+
+def test_from_epoch_seq_input() -> None:
+    seq_input = [1147880044]
+    expected = pl.Series([datetime(2006, 5, 17, 15, 34, 4)])
+    result = pl.from_epoch(seq_input)
+    assert_series_equal(result, expected)
