@@ -17,10 +17,12 @@ from polars.datatypes import (
     Float64,
     Int32,
     Int64,
+    PolarsDataType,
     Time,
     UInt32,
     UInt64,
 )
+from polars.internals.type_aliases import EpochTimeUnit
 from polars.testing import assert_frame_equal, assert_series_equal
 from polars.testing._private import verify_series_and_expr_api
 
@@ -267,9 +269,10 @@ def test_arithmetic(s: pl.Series) -> None:
     assert ((a / 1) == [1.0, 2.0]).sum() == 2
     assert ((a // 2) == [0, 1]).sum() == 2
     assert ((a * 2) == [2, 4]).sum() == 2
-    assert ((1 + a) == [2, 3]).sum() == 2
+    assert ((2 + a) == [3, 4]).sum() == 2
     assert ((1 - a) == [0, -1]).sum() == 2
-    assert ((1 * a) == [1, 2]).sum() == 2
+    assert ((2 * a) == [2, 4]).sum() == 2
+
     # integer division
     assert_series_equal(1 / a, pl.Series([1.0, 0.5]))
     if s.dtype == Int64:
@@ -342,6 +345,9 @@ def test_add_string() -> None:
     result = s + " world"
     assert_series_equal(result, pl.Series(["hello world", "weird world"]))
 
+    result = "pfx:" + s
+    assert_series_equal(result, pl.Series(["pfx:hello", "pfx:weird"]))
+
 
 def test_append_extend() -> None:
     a = pl.Series("a", [1, 2])
@@ -1639,7 +1645,7 @@ def test_str_encode() -> None:
     verify_series_and_expr_api(s, hex_encoded, "str.encode", "hex")
     verify_series_and_expr_api(s, base64_encoded, "str.encode", "base64")
     with pytest.raises(ValueError):
-        s.str.encode("utf8")  # type: ignore[arg-type]
+        s.str.encode("utf8")
 
 
 def test_str_decode() -> None:
@@ -1658,7 +1664,7 @@ def test_str_decode_exception() -> None:
     with pytest.raises(Exception):
         s.str.decode(encoding="base64", strict=True)
     with pytest.raises(ValueError):
-        s.str.decode("utf8")  # type: ignore[arg-type]
+        s.str.decode("utf8")
 
 
 def test_str_replace_str_replace_all() -> None:
@@ -2310,3 +2316,33 @@ def test_repr() -> None:
 def test_builtin_abs() -> None:
     s = pl.Series("s", [-1, 0, 1, None])
     assert abs(s).to_list() == [1, 0, 1, None]
+
+
+@pytest.mark.parametrize(
+    "value, unit, exp, exp_type",
+    [
+        (13285, "d", date(2006, 5, 17), pl.Date),
+        (1147880044, "s", datetime(2006, 5, 17, 15, 34, 4), pl.Datetime),
+        (1147880044 * 1_000, "ms", datetime(2006, 5, 17, 15, 34, 4), pl.Datetime("ms")),
+        (
+            1147880044 * 1_000_000,
+            "us",
+            datetime(2006, 5, 17, 15, 34, 4),
+            pl.Datetime("us"),
+        ),
+        (
+            1147880044 * 1_000_000_000,
+            "ns",
+            datetime(2006, 5, 17, 15, 34, 4),
+            pl.Datetime("ns"),
+        ),
+    ],
+)
+def test_from_epoch_expr(
+    value: int, unit: EpochTimeUnit, exp: date | datetime, exp_type: PolarsDataType
+) -> None:
+    s = pl.Series("timestamp", [value, None])
+    result = pl.from_epoch(s, unit=unit)
+
+    expected = pl.Series("timestamp", [exp, None]).cast(exp_type)
+    assert_series_equal(result, expected)
