@@ -278,3 +278,13 @@ def test_sort_slice_fast_path_5245() -> None:
     assert df.sort("foo").limit(1).select("foo").collect().to_dict(False) == {
         "foo": ["a"]
     }
+
+
+def test_explicit_list_agg_sort_in_groupby() -> None:
+    df = pl.DataFrame({"A": ["a", "a", "a", "b", "b", "a"], "B": [1, 2, 3, 4, 5, 6]})
+    assert (
+        df.groupby("A")
+        .agg(pl.col("B").list().sort(reverse=True))
+        .sort("A")
+        .frame_equal(df.groupby("A").agg(pl.col("B").sort(reverse=True)).sort("A"))
+    )
